#include <stdio.h>
#include <stdint.h>

#define WIN32_LEAN_AND_MEAN
#include <Windows.h>

#include "SDL.h"

int main(int argc, char *argv[]) {
  AllocConsole();
  freopen("CON", "w", stdout);
  freopen("CON", "w", stderr);

  printf("Hello, world!\r\n");

  /* Test C99 compatibility */
  uint32_t leet = 1337;

  /* Test C++11 compatibility */
  auto hehe = 1338;

  printf("Initializing SDL.\n");

  /* Initialize defaults, Video and Audio */
  if((SDL_Init(SDL_INIT_VIDEO|SDL_INIT_AUDIO)==-1)) {
      printf("Could not initialize SDL: %s.\n", SDL_GetError());
      exit(-1);
  }

  printf("SDL initialized.\n");

  /* Have a preference for 8-bit, but accept any depth */
  SDL_Surface *screen;
  screen = SDL_SetVideoMode(640, 480, 8, SDL_SWSURFACE|SDL_ANYFORMAT);
  if ( screen == NULL ) {
      fprintf(stderr, "Couldn't set 640x480x8 video mode: %s\n",
                      SDL_GetError());
      exit(1);
  }
  printf("Set 640x480 at %d bits-per-pixel mode\n",
         screen->format->BitsPerPixel);

  SDL_Surface *image;
  char const *fn = "test95.bmp";

  image = SDL_LoadBMP(fn);
  if (image == NULL) {
    fprintf(stderr, "Couldn't load %s: %s\n", fn, SDL_GetError());
    goto MARK_SDL_QUIT;
  }

  if (SDL_BlitSurface(image, NULL, screen, NULL) < 0) {
    fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());
    goto MARK_SDL_QUIT;
  }

  SDL_UpdateRect(screen, 0, 0, image->w, image->h);

  SDL_FreeSurface(image);

  SDL_Event event;
  while (1) {
    while (SDL_PollEvent(&event)) {
      switch (event.type) {
      case SDL_QUIT:
        goto MARK_SDL_QUIT;
        break;
      }
    }
  }

  MARK_SDL_QUIT:
  printf("Quitting SDL.\n");

  /* Shutdown all subsystems */
  SDL_Quit();

  printf("Quitting....\n");

  return 0;
}
